@@ -82,10 +82,20 @@ var (
 	containerImageAccountLookupTable = map[string]string{
 		"af-south-1":     "877085696533",
 		"ap-east-1":      "800184023465",
+		"ap-southeast-3": "296578399912",
+		"ap-south-2":     "900889452093",
+		"ap-southeast-4": "491585149902",
+		"ap-southeast-7": "121268973566",
 		"cn-north-1":     "918309763551",
 		"cn-northwest-1": "961992271922",
 		"eu-south-1":     "590381155156",
+		"eu-south-2":     "455263428931",
+		"eu-central-2":   "900612956339",
+		"il-central-1":   "066635153087",
 		"me-south-1":     "558608220178",
+		"me-central-1":   "759879836304",
+		"mx-central-1":   "730335286997",
+		"ca-west-1":      "761377655185",
 		"us-gov-east-1":  "151742754352",
 		"us-gov-west-1":  "013241004608",
 	}
